({
    "driver": {
        "properties": {
            "settings": {
                "title": "实例配置",
                "type": "object",
                "properties": {
                    "servers": {
                        "type": "array",
                        "title": "OPC 服务器列表",
                        "items": {
                            "type": "object",
                            "title": "OPC 服务器",
                            "description": "OPC 服务器信息",
                            "properties": {
                                "name": {
                                    "type": "string",
                                    "title": "名称",
                                    "description": "OPC 服务器名称, 用于区分不同的 OPC 服务器"
                                },
                                "host": {
                                    "type": "string",
                                    "format": "ipv4",
                                    "title": "IP",
                                    "fieldType": "ip"
                                },
                                "domain": {
                                    "type": "string",
                                    "title": "计算机名"
                                },
                                "user": {
                                    "type": "string",
                                    "title": "用户名"
                                },
                                "password": {
                                    "type": "string",
                                    "title": "密码",
                                    "fieldType": "password"
                                },
                                "progid": {
                                    "type": "string",
                                    "title": "progId"
                                },
                                "clsid": {
                                    "type": "string",
                                    "title": "clsid",
                                    "description": "未设置时根据 progId 配置自动获取"
                                },
                                "master": {
                                    "type": "boolean",
                                    "title": "是否为主服务器",
                                    "description": "如果勾选则为主服务器"
                                },
                                "enabled": {
                                    "type": "boolean",
                                    "title": "是否启用",
                                    "description": "如果不勾选, 则不会切换到该 OPC 服务器"
                                }
                            },
                            "required": ["name", "host", "domain", "user", "password", "progid"]
                        }
                    },
                    "host": {
                        "type": "string",
                        "format": "ipv4",
                        "title": "主服务器IP",
                        "fieldType": "ip"
                    },
                    "domain": {
                        "type": "string",
                        "title": "主服务器计算机名"
                    },
                    "user": {
                        "type": "string",
                        "title": "主服务器用户名"
                    },
                    "password": {
                        "type": "string",
                        "title": "主服务器密码",
                        "fieldType": "password"
                    },
                    "progid": {
                        "type": "string",
                        "title": "主服务器 progId"
                    },
                    "clsid": {
                        "type": "string",
                        "title": "主服务器 clsid",
                        "description": "未设置时根据 progId 配置自动获取"
                    },
                    "connectType": {
                        "type": "string",
                        "title": "连接类型",
                        "selectType": "single",
                        "selectFace": "flatten",
                        "enum1": ['AUTO', 'MASTER_ONLY', 'BACKUP_ONLY'],
                        "enum_title1": ['自动', '只连主服务器', '只连备用服务器'],
                        "description": "默认为 '自动', 会优先连接主服务器"
                    },
                    "recoveryToMaster": {
                        "type": "boolean",
                        "title": "是否切换回主服务器",
                        "description": "当主服务器恢复时, 是否切换回主服务器. 只有连接类型为 '自动' 时才有效. 如果所有的 OPC 服务器都未设置为主服务器, 则不会切换回主服务器"
                    },
                    "uniqueConnection": {
                        "type": "boolean",
                        "title": "单一连接",
                        "description": "与同一 opc server 只建立一个连接"
                    },
                    "tagCountPerConnection": {
                        "type": "number",
                        "title": "每个连接订阅的数据点数量",
                        "description": "只要未勾选 '单一连接' 时有效"
                    },
                    "itemPrefixName": {
                        "type": "string",
                        "title": "Item前缀",
                        "description": "影响数据点配置中的ItemId"
                    },
                    "interval": {
                        "type": "number",
                        "title": "采集周期 (s)",
                        "description": "数据点的采集周期，不定义默认5秒"
                    },
                    "network": {
                        "type": "object",
                        "title": "通讯监控参数",
                        "properties": {
                            "timeout": {
                                "title": "通讯超时时间(s)",
                                "description": "经过多长时间仪表还没有任何数据上传，认定为通讯故障，默认为周期的3倍",
                                "type": "number"
                            }
                        },
                        "form": [{
                            "key": "timeout",
                            "validate": (v, vs) => {
                                const interval = vs && vs.settings && vs.settings.interval
                                return v <= interval ? "需大于采集周期" : null
                            }
                        }]
                    }
                },
                "required": ["host", "domain", "user", "password", "progid"]
            },
            "tags": {
                "title": "数据点",
                "type": "array",
                "items": {
                    "type": "object",
                    "properties": {
                        "name": {
                            "type": "string",
                            "title": "名称"
                        },
                        "id": {
                            "type": "string",
                            "title": "标识"
                        },
                        "itemid": {
                            "type": "string",
                            "title": "itemid"
                        },
                        "rw": {
                            "type": "boolean",
                            "title": "允许指令写入",
                            "description": "缺省为false"
                        }
                    },
                    "required": ["name", "id", "itemid"]
                }
            },
            "commands": {
                "title": "命令",
                "type": "array",
                "items": {
                    "type": "object",
                    "properties": {
                        "name": {
                            "type": "string",
                            "title": "名称"
                        },
                        "ops": {
                            "type": "array",
                            "title": "指令",
                            "items": {
                                "type": "object",
                                "properties": {
                                    "itemid": {
                                        "type": "string",
                                        "title": "itemid"
                                    },
                                    "param": {
                                        "type": "string",
                                        "title": "绑定表单项",
                                        // "fieldType": 'bindFormItem',
                                        "description": "填写表单项的名称"
                                    },
                                    "value": {
                                        "type": "string",
                                        "title": "默认写入值"
                                    }
                                },
                                "required": ["itemid"]
                            }
                        }
                    }
                }
            }
        }
    },
    "model": {
        "properties": {
            "settings": {
                "title": "模型配置",
                "type": "object",
                "properties": {
                    "servers": {
                        "type": "array",
                        "title": "OPC 服务器列表",
                        "items": {
                            "type": "object",
                            "title": "OPC 服务器",
                            "description": "OPC 服务器信息",
                            "properties": {
                                "name": {
                                    "type": "string",
                                    "title": "名称",
                                    "description": "OPC 服务器名称, 用于区分不同的 OPC 服务器"
                                },
                                "host": {
                                    "type": "string",
                                    "format": "ipv4",
                                    "title": "IP",
                                    "fieldType": "ip"
                                },
                                "domain": {
                                    "type": "string",
                                    "title": "计算机名"
                                },
                                "user": {
                                    "type": "string",
                                    "title": "用户名"
                                },
                                "password": {
                                    "type": "string",
                                    "title": "密码",
                                    "fieldType": "password"
                                },
                                "progid": {
                                    "type": "string",
                                    "title": "progId"
                                },
                                "clsid": {
                                    "type": "string",
                                    "title": "clsid",
                                    "description": "未设置时根据 progId 配置自动获取"
                                },
                                "master": {
                                    "type": "boolean",
                                    "title": "是否为主服务器",
                                    "description": "如果勾选则为主服务器"
                                },
                                "enabled": {
                                    "type": "boolean",
                                    "title": "是否启用",
                                    "description": "如果不勾选, 则不会切换到该 OPC 服务器"
                                }
                            },
                            "required": ["name", "host", "domain", "user", "password", "progid"]
                        }
                    },
                    "host": {
                        "type": "string",
                        "format": "ipv4",
                        "title": "主服务器IP",
                        "fieldType": "ip"
                    },
                    "domain": {
                        "type": "string",
                        "title": "主服务器计算机名"
                    },
                    "user": {
                        "type": "string",
                        "title": "主服务器用户名"
                    },
                    "password": {
                        "type": "string",
                        "title": "主服务器密码",
                        "fieldType": "password"
                    },
                    "progid": {
                        "type": "string",
                        "title": "主服务器 progId"
                    },
                    "clsid": {
                        "type": "string",
                        "title": "主服务器 clsid",
                        "description": "未设置时根据 progId 配置自动获取"
                    },
                    "connectType": {
                        "type": "string",
                        "title": "连接类型",
                        "selectType": "single",
                        "selectFace": "flatten",
                        "enum1": ['AUTO', 'MASTER_ONLY', 'BACKUP_ONLY'],
                        "enum_title1": ['自动', '只连主服务器', '只连备用服务器'],
                        "description": "默认为 '自动', 会优先连接主服务器"
                    },
                    "recoveryToMaster": {
                        "type": "boolean",
                        "title": "是否切换回主服务器",
                        "description": "当主服务器恢复时, 是否切换回主服务器. 只有连接类型为 '自动' 时才有效. 如果所有的 OPC 服务器都未设置为主服务器, 则不会切换回主服务器"
                    },
                    "uniqueConnection": {
                        "type": "boolean",
                        "title": "单一连接",
                        "description": "与同一 opc server 只建立一个连接"
                    },
                    "tagCountPerConnection": {
                        "type": "number",
                        "title": "每个连接订阅的数据点数量",
                        "description": "只要未勾选 '单一连接' 时有效"
                    },
                    "overWrite": {
                        "type": "boolean",
                        "title": "不继承实例的数据点",
                        "description": "默认情况下模型的数据点为其自身的和实例的数据点的并集"
                    },
                    "itemPrefixName": {
                        "type": "string",
                        "title": "Item前缀",
                        "description": "影响数据点配置中的ItemId"
                    },
                    "interval": {
                        "type": "number",
                        "title": "采集周期 (s)",
                        "description": "数据点的采集周期，不定义默认5秒"
                    },
                    "network": {
                        "type": "object",
                        "title": "通讯监控参数",
                        "properties": {
                            "timeout": {
                                "title": "通讯超时时间(s)",
                                "description": "经过多长时间仪表还没有任何数据上传，认定为通讯故障，默认为周期的3倍",
                                "type": "number"
                            }
                        },
                        "form": [{
                            "key": "timeout",
                            "validate": (v, vs) => {
                                const interval = vs && vs.settings && vs.settings.interval
                                return v <= interval ? "需大于采集周期" : null
                            }
                        }]
                    }
                },
                "required": []
            },
            "tags": {
                "title": "数据点",
                "type": "array",
                "items": {
                    "type": "object",
                    "properties": {
                        "name": {
                            "type": "string",
                            "title": "名称"
                        },
                        "id": {
                            "type": "string",
                            "title": "标识"
                        },
                        "itemid": {
                            "type": "string",
                            "title": "itemid"
                        },
                        "rw": {
                            "type": "boolean",
                            "title": "允许指令写入",
                            "description": "缺省为false"
                        }
                    },
                    "required": ["name", "id", "itemid"]
                }
            },
            "commands": {
                "title": "命令",
                "type": "array",
                "items": {
                    "type": "object",
                    "properties": {
                        "name": {
                            "type": "string",
                            "title": "名称"
                        },
                        "ops": {
                            "type": "array",
                            "title": "指令",
                            "items": {
                                "type": "object",
                                "properties": {
                                    "itemid": {
                                        "type": "string",
                                        "title": "itemid"
                                    },
                                    "param": {
                                        "type": "string",
                                        "title": "绑定表单项",
                                        // "fieldType": 'bindFormItem',
                                        "description": "填写表单项的名称"
                                    },
                                    "value": {
                                        "type": "string",
                                        "title": "默认写入值"
                                    }
                                },
                                "required": ["itemid"]
                            }
                        }
                    }
                }
            }
        }
    },
    "device": {
        "properties": {
            "settings": {
                "title": "设备配置",
                "type": "object",
                "properties": {
                    "servers": {
                        "type": "array",
                        "title": "OPC 服务器列表",
                        "items": {
                            "type": "object",
                            "title": "OPC 服务器",
                            "description": "OPC 服务器信息",
                            "properties": {
                                "name": {
                                    "type": "string",
                                    "title": "名称",
                                    "description": "OPC 服务器名称, 用于区分不同的 OPC 服务器"
                                },
                                "host": {
                                    "type": "string",
                                    "format": "ipv4",
                                    "title": "IP",
                                    "fieldType": "ip"
                                },
                                "domain": {
                                    "type": "string",
                                    "title": "计算机名"
                                },
                                "user": {
                                    "type": "string",
                                    "title": "用户名"
                                },
                                "password": {
                                    "type": "string",
                                    "title": "密码",
                                    "fieldType": "password"
                                },
                                "progid": {
                                    "type": "string",
                                    "title": "progId"
                                },
                                "clsid": {
                                    "type": "string",
                                    "title": "clsid",
                                    "description": "未设置时根据 progId 配置自动获取"
                                },
                                "master": {
                                    "type": "boolean",
                                    "title": "是否为主服务器",
                                    "description": "如果勾选则为主服务器"
                                },
                                "enabled": {
                                    "type": "boolean",
                                    "title": "是否启用",
                                    "description": "如果不勾选, 则不会切换到该 OPC 服务器"
                                }
                            },
                            "required": ["name", "host", "domain", "user", "password", "progid"]
                        }
                    },
                    "host": {
                        "type": "string",
                        "format": "ipv4",
                        "title": "主服务器IP",
                        "fieldType": "ip"
                    },
                    "domain": {
                        "type": "string",
                        "title": "主服务器计算机名"
                    },
                    "user": {
                        "type": "string",
                        "title": "主服务器用户名"
                    },
                    "password": {
                        "type": "string",
                        "title": "主服务器密码",
                        "fieldType": "password"
                    },
                    "progid": {
                        "type": "string",
                        "title": "主服务器 progId"
                    },
                    "clsid": {
                        "type": "string",
                        "title": "主服务器 clsid",
                        "description": "未设置时根据 progId 配置自动获取"
                    },
                    "connectType": {
                        "type": "string",
                        "title": "连接类型",
                        "selectType": "single",
                        "selectFace": "flatten",
                        "enum1": ['AUTO', 'MASTER_ONLY', 'BACKUP_ONLY'],
                        "enum_title1": ['自动', '只连主服务器', '只连备用服务器'],
                        "description": "默认为 '自动', 会优先连接主服务器"
                    },
                    "recoveryToMaster": {
                        "type": "boolean",
                        "title": "是否切换回主服务器",
                        "description": "当主服务器恢复时, 是否切换回主服务器. 只有连接类型为 '自动' 时才有效. 如果所有的 OPC 服务器都未设置为主服务器, 则不会切换回主服务器"
                    },
                    "uniqueConnection": {
                        "type": "boolean",
                        "title": "单一连接",
                        "description": "与同一 opc server 只建立一个连接"
                    },
                    "tagCountPerConnection": {
                        "type": "number",
                        "title": "每个连接订阅的数据点数量",
                        "description": "只要未勾选 '单一连接' 时有效"
                    },
                    "overWrite": {
                        "type": "boolean",
                        "title": "不继承模型的数据点",
                        "description": "默认情况下资产数据点为其自身的和模型的数据点的合集"
                    },
                    "itemPrefixName": {
                        "type": "string",
                        "title": "Item前缀",
                        "description": "影响数据点配置中的ItemId"
                    },
                    "interval": {
                        "type": "number",
                        "title": "采集周期 (s)",
                        "description": "数据点的采集周期，不定义默认5秒"
                    },
                    "network": {
                        "type": "object",
                        "title": "通讯监控参数",
                        "properties": {
                            "timeout": {
                                "title": "通讯超时时间(s)",
                                "description": "经过多长时间仪表还没有任何数据上传，认定为通讯故障，默认为周期的3倍",
                                "type": "number"
                            }
                        },
                        "form": [{
                            "key": "timeout",
                            "validate": (v, vs) => {
                                const interval = vs && vs.settings && vs.settings.interval
                                return v <= interval ? "需大于采集周期" : null
                            }
                        }]
                    }
                },
                "required": []
            },
            "tags": {
                "title": "数据点",
                "type": "array",
                "items": {
                    "type": "object",
                    "properties": {
                        "name": {
                            "type": "string",
                            "title": "名称"
                        },
                        "id": {
                            "type": "string",
                            "title": "标识"
                        },
                        "itemid": {
                            "type": "string",
                            "title": "itemid"
                        },
                        "rw": {
                            "type": "boolean",
                            "title": "允许指令写入",
                            "description": "缺省为false"
                        }
                    },
                    "required": ["name", "id", "itemid"]
                }
            },
            "commands": {
                "title": "命令",
                "type": "array",
                "items": {
                    "type": "object",
                    "properties": {
                        "name": {
                            "type": "string",
                            "title": "名称"
                        },
                        "ops": {
                            "type": "array",
                            "title": "指令",
                            "items": {
                                "type": "object",
                                "properties": {
                                    "itemid": {
                                        "type": "string",
                                        "title": "itemid"
                                    },
                                    "param": {
                                        "type": "string",
                                        "title": "绑定表单项",
                                        // "fieldType": 'bindFormItem',
                                        "description": "填写表单项的名称"
                                    },
                                    "value": {
                                        "type": "string",
                                        "title": "默认写入值"
                                    }
                                },
                                "required": ["itemid"]
                            }
                        }
                    }
                }
            }
        }
    }
})
